@@ -1,80 +1,17 @@
-package Querylet::Output::Excel::OLE;
-use base qw(Querylet::Output);
-
 use strict;
 use warnings;
+package Querylet::Output::Excel::OLE;
+{
+  $Querylet::Output::Excel::OLE::VERSION = '0.143';
+}
+use parent qw(Querylet::Output);
+# ABSTRACT: output query results to Excel via OLE
 
-=head1 NAME
-
-Querylet::Output::Excel::OLE - output query results to Excel via OLE
-
-=head1 VERSION
-
-version 0.142
-
- $Id: /my/cs/projects/q/excel/trunk/lib/Querylet/Output/Excel/OLE.pm 28050 2006-11-14T23:40:46.906717Z rjbs  $
-
-=cut
-
-our $VERSION = '0.142';
 use Carp;
 
-=head1 SYNOPSIS
-
- use Querylet::Output::Excel::OLE;
- use Querylet;
-
- database: bogosity
-
- query:
-   SELECT detector_id, measurement
-   FROM   bogon_detections
-
- output format: excel
-
-=head1 DESCRIPTION
-
-Querylet::Output::Excel::OLE provides an output handler for Querylet that will
-create a new instance of Microsoft Excel using Win32::OLE and populate a
-worksheet with the query results.
-
-=head1 METHODS
-
-This module isa Querylet::Output, and implements the interface described by
-that module.
-
-=over 4
-
-=item C<< default_type >>
-
-The Excel::OLE handler is by default registered for the 'excel' type.
-
-=cut
 
 sub default_type { 'excel' }
 
-=item C<< handler >>
-
-The Querylet::Output::Excel::OLE handler returns a coderef that, when called,
-will create an Excel.Application object, then create a workbook, and then
-populate its worksheet with the querylet's results.
-
-If the "excel_workbook" and "excel_worksheet" options are set, it will attempt
-to open the named workbook file and put its results into the named worksheet,
-creating it if necessary.  If the workbook, but not worksheet, is set, it will
-create a new worksheet in the named workbook.
-
-If the "excel_postprocessing_callback" option is set, the handler will try to
-evaluate it into a code reference, the code reference will be called after all
-other processing is done.  It will be passed a hash reference with the
-following keys:
-
- query     - the Querylet::Query object being output
- excel     - the Excel.Application object
- workbook  - the Workbook object
- worksheet - the Worksheet object
-
-=cut
 
 sub handler { \&_to_excel }
 
@@ -132,22 +69,6 @@ sub _to_excel {
 	}
 }
 
-=back
-
-=head1 FUNCTIONS
-
-=over 4
-
-=item C<< column_name($column_number) >>
-
-This converts a column number to a column name, Excel style.  In other words:
-
-    1 -> A
-   26 -> Z
-   27 -> AA
- 2600 -> CUZ
-
-=cut
 
 sub column_name {
 	my ($number) = @_;
@@ -162,26 +83,91 @@ sub column_name {
 	return $name;
 }
 
-=back
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Querylet::Output::Excel::OLE - output query results to Excel via OLE
+
+=head1 VERSION
+
+version 0.143
+
+=head1 SYNOPSIS
+
+ use Querylet::Output::Excel::OLE;
+ use Querylet;
+
+ database: bogosity
+
+ query:
+   SELECT detector_id, measurement
+   FROM   bogon_detections
+
+ output format: excel
+
+=head1 DESCRIPTION
+
+Querylet::Output::Excel::OLE provides an output handler for Querylet that will
+create a new instance of Microsoft Excel using Win32::OLE and populate a
+worksheet with the query results.
+
+=head1 METHODS
+
+This module isa Querylet::Output, and implements the interface described by
+that module.
+
+=head2 default_type
+
+The Excel::OLE handler is by default registered for the 'excel' type.
+
+=head2 handler
+
+The Querylet::Output::Excel::OLE handler returns a coderef that, when called,
+will create an Excel.Application object, then create a workbook, and then
+populate its worksheet with the querylet's results.
+
+If the "excel_workbook" and "excel_worksheet" options are set, it will attempt
+to open the named workbook file and put its results into the named worksheet,
+creating it if necessary.  If the workbook, but not worksheet, is set, it will
+create a new worksheet in the named workbook.
+
+If the "excel_postprocessing_callback" option is set, the handler will try to
+evaluate it into a code reference, the code reference will be called after all
+other processing is done.  It will be passed a hash reference with the
+following keys:
+
+ query     - the Querylet::Query object being output
+ excel     - the Excel.Application object
+ workbook  - the Workbook object
+ worksheet - the Worksheet object
+
+=head1 FUNCTIONS
+
+=head2 column_name
+
+  column_name($column_number)
+
+This converts a column number to a column name, Excel style.  In other words:
+
+    1 -> A
+   26 -> Z
+   27 -> AA
+ 2600 -> CUZ
 
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-querylet-output-excel-ole@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2004 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2004-2006, Ricardo SIGNES, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
